/*----------------------------------------------------------------------------
 *      RL-ARM - RTX
 *----------------------------------------------------------------------------
 *      Name:    BLINKY.C
 *      Purpose: RTX example program
 *----------------------------------------------------------------------------
 * All files for ADuCM360 provided by ADI, including this file, are
 * provided  as is without warranty of any kind, either expressed or implied.
 * The user assumes any and all risk from the use of this code.
 * It is the responsibility of the person integrating this code into an application
 * to ensure that the resulting application performs as required and is safe.
 *---------------------------------------------------------------------------*/

#include <cmsis_os.h>
#include <ADuCM360.H>
#include "LED.h"

osThreadId t_ledOn;                         /* assigned task id of task: ledOn   */
osThreadId t_ledOff;                        /* assigned task id of task: ledOff  */


/*----------------------------------------------------------------------------
  Task 1 'ledOn': switches the LED on
 *---------------------------------------------------------------------------*/
void ledOn (void const *argument) {
  for (;;) {
    LED_On(0);                           /* Turn LED On                       */
    osSignalSet (t_ledOff, 0x0001);      /* send event to task 'ledoff'       */
    osDelay (500);                       /* delay 500 ms                      */
  }
}

/*----------------------------------------------------------------------------
  Task 2 'ledOff': switches the LED off
 *---------------------------------------------------------------------------*/
void ledOff (void const *argument) {
  for (;;) {
    osSignalWait (0x0001, osWaitForever);   /* wait for an event flag 0x0001     */
    osDelay (250);                          /* delay 250 ms                      */
    LED_Off(0);                             /* Turn LED Off                      */
  }
}

osThreadDef(ledOn,  osPriorityNormal, 1, 0);
osThreadDef(ledOff, osPriorityNormal, 1, 0);

/*----------------------------------------------------------------------------
  Main: Initialize and start RTX Kernel
 *---------------------------------------------------------------------------*/
int main (void) {

  SystemCoreClockUpdate();
  LED_Init();

  t_ledOn  = osThreadCreate(osThread(ledOn),  NULL);
  t_ledOff = osThreadCreate(osThread(ledOff), NULL);
  osDelay(osWaitForever);
  while(1);

}
